@@ -1,5 +1,5 @@
 """Run main module entry point (start background worker)."""
-from feltoken.node.background_worker import main
+from feltoken.algorithm.train import main
 
 if __name__ == "__main__":
     main()
